@@ -1,7 +1,7 @@
 import time
 from datetime import datetime, timedelta
 
-from src import enums, exceptions
+from defi_common import enums, exceptions
 
 
 def get_time_now() -> int:
